# Astrocyte ATAC-seq analysis Workflow Package

This SOP describes the analysis pipeline of downstream analysis of ChIP-seq sequencing data. This pipeline includes (1) Quality control using Deeptools, (2) Peak annotation, (3) Differential peak analysis, and (4) motif analysis. BAM files and SORTED peak BED files selected as input. For each sample this workflow:

    1) Annotate all peaks using ChipSeeker
    2) Qulity control and signal profiling with Deeptools
    3) Find differential expressed peaks using DiffBind
    4) Annotate all differentially expressed peaks
    5) Using MEME-ChIP in motif finding for both original peaks and differently expressed peaks



## Annotations used in the pipeline

    ChipSeeker - Known gene from Bioconductor [TxDb annotation](https://bioconductor.org/packages/release/BiocViews.html#___TxDb)
    Deeptools - RefGene downloaded from UCSC Table browser




## Workflow Parameters

    bam - Choose all ChIP-seq alignment files for analysis.
    genome - Choose a genomic reference (genome).
    peaks - Choose all the peak files for analysis. All peaks should be sorted by the user
    design - Choose the file with the experiment design information. CSV format
    toppeak - The number of top peaks used for motif analysis. Default is all



## Design file
  + The Design file is a tab-delimited file with 4 columns for Single-End and 5 columns for Paired-End.  Letter, numbers, and underlines can be used in the names. However, the names must begin with a letter. Columns must be as follows:

    sample_id
        The id of the sample. This will be the header in output files, please make sure it is concise
    experiment_id
        Same name given for all replicates of treatment. Will be used for the consensus header.
    replicate
        Replicate number
    fastq_read1
        Name of fastq file 1 for SE or PE data
    fastq_read2
        Name of fastq file 2 for PE data
    
  + See [HERE](/docs/design_ENCSR451NAE_PE.txt) for an example design file, paired-end
  + See [HERE](/docs/design_ENCSR265ZXX_SE.txt) for an example design file, single-end

## Common Errors
If you find an error, please let the [BICF](mailto:BICF@UTSouthwestern.edu) know and we will add it here.

## Citation
Please cite individual programs and versions used [HERE](docs/references.md), and the pipeline doi: coming soon. Please cite in publications: Pipeline was developed by BICF from funding provided by Cancer Prevention and Research Institute of Texas (RP150596).

### Credits
This example worklow is derived from original scripts kindly contributed by the Bioinformatic Core Facility ([BICF](https://www.utsouthwestern.edu/labs/bioinformatics/)), in the [Department of Bioinformatics](https://www.utsouthwestern.edu/departments/bioinformatics/).

