#!/usr/bin/env python3

'''Generate FRiP from data.'''

import sys
import os
import argparse
import utils
import logging
import subprocess


# SETTINGS

logger = logging.getLogger(__name__)
logger.addHandler(logging.NullHandler())
logger.propagate = False
logger.setLevel(logging.INFO)


EPILOG = '''
For more details:
        %(prog)s --help
'''


def parse_arguments():

    parser = argparse.ArgumentParser(
        description=__doc__, epilog=EPILOG,
        formatter_class=argparse.RawDescriptionHelpFormatter)

    parser.add_argument('-p', '--peak',
                        help='The peak file to perform qc on.',
                        required=True)

    parser.add_argument('-t', '--tag',
                        help="The tagAlign file to perform qc on.",
                        required=True)

    args = parser.parse_args()

    args = parser.parse_args()
    return args

# Functions

def frip(tag, peak):
    '''Calculate FRiP'''

    prefix = os.path.basename(utils.strip_extensions(peak, ['.narrowPeak']))

    frip_qc = '{}.frip.qc'.format(prefix)


    cmd = 'bedtools intersect -a {} -b {} -wa -u'
    cmd = cmd.format(
        tag, # ta
        peak) # peak
    out, err = utils.run_pipe([
        '%s' % (cmd),
        'wc -l'
        ])
    val2 = utils.count_lines(tag)
    qc_val =  str(float(out)/float(val2))
    f = open(frip_qc, 'w+')
    f.write(qc_val)
    return frip_qc


def main():
    # read params
    args = parse_arguments()
    tag = args.tag
    peak = args.peak

    handler = logging.FileHandler('frip.log')
    logger.addHandler(handler)

    frip_qc = frip(tag, peak)


if __name__=='__main__':
    main()
